@@ -28,9 +28,9 @@ MAX_RETRY_DOWNLOAD = 10
 MAX_WAIT = 360
 WAIT_TIME_IN_SECONDS = 10
 
-SSE_C_ALGORITHM = u"x-amz-server-side-encryption-customer-algorithm"
-SSE_C_KEY = u"x-amz-server-side-encryption-customer-key"
-SSE_C_AES = u"AES256"
+SSE_C_ALGORITHM = "x-amz-server-side-encryption-customer-algorithm"
+SSE_C_KEY = "x-amz-server-side-encryption-customer-key"
+SSE_C_AES = "AES256"
 
 SnowflakeChunk = namedtuple('SnowflakeChunk', [
     'url',  # S3 bucket URL to download the chunk
@@ -43,9 +43,7 @@ logger = getLogger(__name__)
 
 
 class SnowflakeChunkDownloader(object):
-    u"""
-    Large Result set chunk downloader class.
-    """
+    """Large Result set chunk downloader class."""
 
     def _pre_init(self, chunks, connection, cursor, qrmk, chunk_headers,
                   query_result_format='JSON',
@@ -68,17 +66,17 @@ class SnowflakeChunkDownloader(object):
             self._effective_threads = 1
 
         for idx, chunk in enumerate(chunks):
-            logger.debug(u"queued chunk %d: rowCount=%s", idx,
-                         chunk[u'rowCount'])
+            logger.debug("queued chunk %d: rowCount=%s", idx,
+                         chunk['rowCount'])
             self._chunks[idx] = SnowflakeChunk(
-                url=chunk[u'url'],
+                url=chunk['url'],
                 result_data=None,
                 ready=False,
-                row_count=int(chunk[u'rowCount']))
+                row_count=int(chunk['rowCount']))
 
-        logger.debug(u'prefetch threads: %s, '
-                     u'number of chunks: %s, '
-                     u'effective threads: %s',
+        logger.debug('prefetch threads: %s, '
+                     'number of chunks: %s, '
+                     'effective threads: %s',
                      prefetch_threads,
                      self._chunk_size,
                      self._effective_threads)
@@ -103,14 +101,12 @@ class SnowflakeChunkDownloader(object):
         self._next_chunk_to_download = self._effective_threads
 
     def _download_chunk(self, idx):
-        """
-        Downloads a chunk asynchronously
-        """
-        logger.debug(u'downloading chunk %s/%s', idx + 1, self._chunk_size)
+        """Downloads a chunk asynchronously."""
+        logger.debug('downloading chunk %s/%s', idx + 1, self._chunk_size)
         headers = {}
         if self._chunk_headers is not None:
             headers = self._chunk_headers
-            logger.debug(u'use chunk headers from result')
+            logger.debug('use chunk headers from result')
         elif self._qrmk is not None:
             headers[SSE_C_ALGORITHM] = SSE_C_AES
             headers[SSE_C_KEY] = self._qrmk
@@ -120,10 +116,10 @@ class SnowflakeChunkDownloader(object):
         sleep_timer = 1
         for retry in range(10):
             try:
-                logger.debug(u"started getting the result set %s: %s",
+                logger.debug("started getting the result set %s: %s",
                              idx + 1, self._chunks[idx].url)
                 result_data = self._fetch_chunk(self._chunks[idx].url, headers)
-                logger.debug(u"finished getting the result set %s: %s",
+                logger.debug("finished getting the result set %s: %s",
                              idx + 1, self._chunks[idx].url)
 
                 if isinstance(result_data, ResultIterWithTimings):
@@ -140,27 +136,25 @@ class SnowflakeChunkDownloader(object):
                         ready=True)
                     self._chunk_cond.notify_all()
                     logger.debug(
-                        u'added chunk %s/%s to a chunk list.', idx + 1,
+                        'added chunk %s/%s to a chunk list.', idx + 1,
                         self._chunk_size)
                 break
             except Exception as e:
                 last_error = e
                 sleep_timer = backoff.next_sleep(1, sleep_timer)
                 logger.exception(
-                    u'Failed to fetch the large result set chunk %s/%s for the %s th time, backing off for %s s',
+                    'Failed to fetch the large result set chunk %s/%s for the %s th time, backing off for %s s',
                     idx + 1, self._chunk_size, retry + 1, sleep_timer)
                 time.sleep(sleep_timer)
         else:
             self._downloader_error = last_error
 
     def next_chunk(self):
-        """
-        Gets the next chunk if ready
-        """
+        """Gets the next chunk if ready."""
         logger.debug(
-            u'next_chunk_to_consume={next_chunk_to_consume}, '
-            u'next_chunk_to_download={next_chunk_to_download}, '
-            u'total_chunks={total_chunks}'.format(
+            'next_chunk_to_consume={next_chunk_to_consume}, '
+            'next_chunk_to_download={next_chunk_to_download}, '
+            'total_chunks={total_chunks}'.format(
                 next_chunk_to_consume=self._next_chunk_to_consume + 1,
                 next_chunk_to_download=self._next_chunk_to_download + 1,
                 total_chunks=self._chunk_size))
@@ -177,8 +171,8 @@ class SnowflakeChunkDownloader(object):
             raise self._downloader_error
 
         for attempt in range(MAX_RETRY_DOWNLOAD):
-            logger.debug(u'waiting for chunk %s/%s'
-                         u' in %s/%s download attempt',
+            logger.debug('waiting for chunk %s/%s'
+                         ' in %s/%s download attempt',
                          self._next_chunk_to_consume + 1,
                          self._chunk_size,
                          attempt + 1,
@@ -191,8 +185,8 @@ class SnowflakeChunkDownloader(object):
                     if self._chunks[self._next_chunk_to_consume].ready:
                         done = True
                         break
-                    logger.debug(u'chunk %s/%s is NOT ready to consume'
-                                 u' in %s/%s(s)',
+                    logger.debug('chunk %s/%s is NOT ready to consume'
+                                 ' in %s/%s(s)',
                                  self._next_chunk_to_consume + 1,
                                  self._chunk_size,
                                  (wait_counter + 1) * WAIT_TIME_IN_SECONDS,
@@ -200,8 +194,8 @@ class SnowflakeChunkDownloader(object):
                     self._chunk_cond.wait(WAIT_TIME_IN_SECONDS)
             else:
                 logger.debug(
-                    u'chunk %s/%s is still NOT ready. Restarting chunk '
-                    u'downloader threads',
+                    'chunk %s/%s is still NOT ready. Restarting chunk '
+                    'downloader threads',
                     self._next_chunk_to_consume + 1,
                     self._chunk_size)
                 self._pool.shutdown(wait=False)  # terminate the thread pool
@@ -217,11 +211,11 @@ class SnowflakeChunkDownloader(object):
                 self._cursor,
                 OperationalError,
                 {
-                    u'msg': u'The result set chunk download fails or hang for '
-                            u'unknown reason.',
-                    u'errno': ER_CHUNK_DOWNLOAD_FAILED
+                    'msg': 'The result set chunk download fails or hang for '
+                            'unknown reason.',
+                    'errno': ER_CHUNK_DOWNLOAD_FAILED
                 })
-        logger.debug(u'chunk %s/%s is ready to consume',
+        logger.debug('chunk %s/%s is ready to consume',
                      self._next_chunk_to_consume + 1,
                      self._chunk_size)
 
@@ -230,9 +224,7 @@ class SnowflakeChunkDownloader(object):
         return ret
 
     def terminate(self):
-        """
-        Terminates downloading the chunks.
-        """
+        """Terminates downloading the chunks."""
         if hasattr(self, u'_pool') and self._pool is not None:
             self._pool.shutdown()
             self._pool = None
@@ -245,23 +237,21 @@ class SnowflakeChunkDownloader(object):
             pass
 
     def _fetch_chunk(self, url, headers):
-        """
-        Fetch the chunk from S3.
-        """
+        """Fetch the chunk from S3."""
         handler = JsonBinaryHandler(is_raw_binary_iterator=True) \
             if self._query_result_format == 'json' else \
             ArrowBinaryHandler(self._cursor, self._connection)
 
         return self._connection.rest.fetch(
-            u'get', url, headers,
+            'get', url, headers,
             timeout=DEFAULT_REQUEST_TIMEOUT,
             is_raw_binary=True,
             binary_data_handler=handler)
 
 
 class ResultIterWithTimings:
-    DOWNLOAD = u"download"
-    PARSE = u"parse"
+    DOWNLOAD = "download"
+    PARSE = "parse"
 
     def __init__(self, it, timings):
         self._it = it
@@ -278,17 +268,13 @@ class ResultIterWithTimings:
 
 
 class RawBinaryDataHandler:
-    """
-    Abstract class being passed to network.py to handle raw binary data
-    """
+    """Abstract class being passed to network.py to handle raw binary data."""
     def to_iterator(self, raw_data_fd, download_time):
         pass
 
 
 class JsonBinaryHandler(RawBinaryDataHandler):
-    """
-    Convert result chunk in json format into interator
-    """
+    """Convert result chunk in json format into interator."""
     def __init__(self, is_raw_binary_iterator):
         self._is_raw_binary_iterator = is_raw_binary_iterator
 
