@@ -7,12 +7,12 @@
 namespace sf
 {
 
-Logger CArrowIterator::logger("snowflake.connector.CArrowIterator");
+Logger* CArrowIterator::logger = new Logger("snowflake.connector.CArrowIterator");
 
 CArrowIterator::CArrowIterator(std::vector<std::shared_ptr<arrow::RecordBatch>>* batches) :
   m_cRecordBatches(batches)
 {
-  logger.debug("Arrow BatchSize: %d", batches->size());
+  logger->debug(__FILE__, __func__, __LINE__, "Arrow BatchSize: %d", batches->size());
 }
 
 }
